@@ -12,7 +12,7 @@ from typing import Union
 
 from chained_accounts import ChainedAccount
 from eth_typing.evm import ChecksumAddress
-from web3 import Web3
+from eth_utils.address import to_checksum_address
 from web3.datastructures import AttributeDict
 
 from telliot_core.model.endpoints import RPCEndpoint
@@ -34,7 +34,7 @@ class Contract:
         account: Optional[ChainedAccount] = None,
     ):
 
-        self.address = Web3.toChecksumAddress(address)
+        self.address = to_checksum_address(address)
         self.abi = abi
         self.node = node
         self.contract = None
@@ -143,10 +143,16 @@ class Contract:
             tx_dict = {
                 "from": acc.address,
                 "nonce": acc_nonce,
-                "gas": gas_limit,
-                "chainId": self.node.chain_id,
             }
+            # Estimate gas_limit if not provided
+            if gas_limit is None:
+                try:
+                    gas_limit = transaction.estimateGas(tx_dict)
+                except Exception as e:
+                    msg = f"Contract.write({func_name}) error: Unable to estimate gas"
+                    return None, error_status(msg, e=e, log=logger.error)
 
+            tx_dict["gas"] = gas_limit
             # use legacy gas strategy if only legacy gas price is provided
             if legacy_gas_price is not None:
 
