@@ -101,6 +101,13 @@ default_chain_list = [
         network="mainnet",
         currency=EVMCurrency(name="Arbitrum Ether", symbol="ETH", decimals=18),
     ),
+    Chain(
+        chain_id=421613,
+        name="Arbitrum Goerli",
+        chain="Arbitrum-goerli",
+        network="testnet-goerli",
+        currency=EVMCurrency(name="Arbitrum Goerli Ether", symbol="AGOR", decimals=18),
+    ),
     Chain(
         chain_id=10200,
         name="Chiado Testnet",
@@ -108,6 +115,34 @@ default_chain_list = [
         network="testnet",
         currency=EVMCurrency(name="Chiado xDai", symbol="XDAI", decimals=18),
     ),
+    Chain(
+        chain_id=100,
+        name="gnosis",
+        chain="gnosis",
+        network="mainnet",
+        currency=EVMCurrency(name="xDai", symbol="XDAI", decimals=18),
+    ),
+    Chain(
+        chain_id=10,
+        name="optimism",
+        chain="optimism",
+        network="mainnet",
+        currency=EVMCurrency(name="Optimism Ether", symbol="ETH", decimals=18),
+    ),
+    Chain(
+        chain_id=420,
+        name="optimism-goerli",
+        chain="optimism-goerli",
+        network="testnet-goerli",
+        currency=EVMCurrency(name="Optimism Ether", symbol="ETH", decimals=18),
+    ),
+    Chain(
+        chain_id=3141,
+        name="filecoin-hyperspace",
+        chain="filecoin-hyperspace",
+        network="testnet",
+        currency=EVMCurrency(name="Testnet Filecoin", symbol="TFIL", decimals=18),
+    ),
 ]
 
 
