@@ -113,7 +113,7 @@ default_endpoint_list = [
         provider="Matic",
         network="mainnet",
         url="https://rpc-mainnet.matic.network",
-        explorer="https://matic.network",
+        explorer="https://polygonscan.com/",
     ),
     RPCEndpoint(
         chain_id=122,
@@ -171,6 +171,13 @@ default_endpoint_list = [
         url="https://arbitrum-mainnet.infura.io/v3/{INFURA_API_KEY}",
         explorer="https://arbiscan.io",
     ),
+    RPCEndpoint(
+        chain_id=421613,
+        provider="Infura",
+        network="Arbitrum Goerli",
+        url="https://arbitrum-goerli.infura.io/v3/{INFURA_API_KEY}",
+        explorer="https://goerli.arbiscan.io/",
+    ),
     RPCEndpoint(
         chain_id=10200,
         provider="blockscout",
@@ -178,6 +185,34 @@ default_endpoint_list = [
         url="https://rpc.chiadochain.net",
         explorer="https://blockscout.chiadochain.net/",
     ),
+    RPCEndpoint(
+        chain_id=100,
+        provider="ankr",
+        network="gnosis",
+        url="https://rpc.ankr.com/gnosis",
+        explorer="https://gnosisscan.io",
+    ),
+    RPCEndpoint(
+        chain_id=10,
+        provider="infura",
+        network="optimism",
+        url="https://optimism-mainnet.infura.io/v3/{INFURA_API_KEY}",
+        explorer="https://optimistic.etherscan.io/",
+    ),
+    RPCEndpoint(
+        chain_id=420,
+        provider="infura",
+        network="optimism-goerli",
+        url="https://optimism-goerli.infura.io/v3/{INFURA_API_KEY}",
+        explorer="https://goerli-optimism.etherscan.io/",
+    ),
+    RPCEndpoint(
+        chain_id=3141,
+        provider="Filecoin",
+        network="filecoin-hyperspace",
+        url="https://api.hyperspace.node.glif.io/rpc/v1",
+        explorer="https://hyperspace.filfox.info/",
+    ),
 ]
 
 
